==> 0.13.0.tar.gz: example/lib/bloc_dynamic_form/dynamic_form_screen.dart <==
import 'package:dynamic_forms/dynamic_forms.dart';
import 'package:example/bloc_dynamic_form/dynamic_form_bloc.dart';
import 'package:example/bloc_dynamic_form/dynamic_form_container.dart';
import 'package:example/bloc_dynamic_form/dynamic_form_event.dart';
import 'package:example/bloc_dynamic_form/dynamic_form_state.dart';
import 'package:flutter/material.dart';
import 'package:flutter/widgets.dart' as flutter;
import 'package:flutter_bloc/flutter_bloc.dart';

class DynamicFormScreen extends StatelessWidget {
  @override
  Widget build(BuildContext context) {
    return Scaffold(
      body: Center(
        child: SingleChildScrollView(
          child: BlocListener<DynamicFormBloc, DynamicFormState>(
            listener: (context, state) {
              if (state.resultProperties != null &&
                  state.resultProperties.isNotEmpty) {
                _displayDialog(context, state.resultProperties);
              }
            },
            child: BlocBuilder<DynamicFormBloc, DynamicFormState>(
              builder: (context, state) {
                Column result = Column(children: <Widget>[
                  DynamicFormContainer(),
                ]);

                if (!state.isLoading) {
                  result.children.add(DynamicFormButtonRow(state));
                }
                return result;
              },
            ),
          ),
        ),
      ),
    );
  }

  void _displayDialog(BuildContext context,
      List<FormPropertyValue> resultPropertyValues) async {
    var bloc = BlocProvider.of<DynamicFormBloc>(context);
    return showDialog(
      context: context,
      builder: (context) {
        return AlertDialog(
          title: flutter.Text('Form data'),
          content: flutter.Container(
            width: double.maxFinite,
            height: 300.0,
            child: ListView(
              padding: EdgeInsets.all(8.0),
              //map List of our data to the ListView
              children: resultPropertyValues
                  .map((riv) =>
                      flutter.Text("${riv.id} ${riv.property} ${riv.value}"))
                  .toList(),
            ),
          ),
          actions: <Widget>[
            FlatButton(
              child: flutter.Text('Ok'),
              onPressed: () {
                bloc.add(ClearFormDataEvent());
                Navigator.of(context).pop();
              },
            )
          ],
        );
      },
    );
  }
}

class DynamicFormButtonRow extends StatelessWidget {
  final DynamicFormState state;

  const DynamicFormButtonRow(
    this.state, {
    Key key,
  }) : super(key: key);

  @override
  Widget build(BuildContext context) {
    var bloc = BlocProvider.of<DynamicFormBloc>(context);
    return Row(
      mainAxisSize: MainAxisSize.max,
      mainAxisAlignment: MainAxisAlignment.center,
      children: <Widget>[
        OutlineButton(
          child: Row(
            children: <Widget>[
              flutter.Text("Cancel"),
              SizedBox(width: 10),
              Icon(Icons.cancel, color: Colors.red),
            ],
          ),
          onPressed: () {
            Navigator.pop(context);
          },
        ),
        SizedBox(width: 10),
        OutlineButton(
          child: Row(
            children: <Widget>[
              flutter.Text("Clear"),
              SizedBox(width: 10),
              Icon(Icons.clear_all, color: Colors.red),
            ],
          ),
          onPressed: () {
            bloc.add(ClearFormEvent());
          },
        ),
        SizedBox(width: 10),
        OutlineButton(
          child: Row(
            children: <Widget>[
              flutter.Text("Ok"),
              SizedBox(width: 10),
              Icon(
                Icons.check_circle,
                color: Colors.green,
              ),
            ],
          ),
          onPressed: state.isValid
              ? () {
                  bloc.add(RequestFormDataEvent());
                }
              : null,
        )
      ],
    );
  }
}

==> 0.14.0.tar.gz: example/lib/bloc_dynamic_form/dynamic_form_screen.dart <==
import 'package:dynamic_forms/dynamic_forms.dart';
import 'package:example/bloc_dynamic_form/dynamic_form_bloc.dart';
import 'package:example/bloc_dynamic_form/dynamic_form_container.dart';
import 'package:example/bloc_dynamic_form/dynamic_form_event.dart';
import 'package:example/bloc_dynamic_form/dynamic_form_state.dart';
import 'package:flutter/material.dart';
import 'package:flutter/widgets.dart' as flutter;
import 'package:flutter_bloc/flutter_bloc.dart';

class DynamicFormScreen extends StatelessWidget {
  @override
  Widget build(BuildContext context) {
    return Scaffold(
      body: Center(
        child: SingleChildScrollView(
          child: BlocListener<DynamicFormBloc, DynamicFormState>(
            listener: (context, state) {
              if (state.resultProperties != null &&
                  state.resultProperties.isNotEmpty) {
                _displayDialog(context, state.resultProperties);
              }
            },
            child: BlocBuilder<DynamicFormBloc, DynamicFormState>(
              builder: (context, state) {
                return Column(
                  children: [
                    DynamicFormContainer(),
                    if (!state.isLoading) DynamicFormButtonRow(state)
                  ],
                );
              },
            ),
          ),
        ),
      ),
    );
  }

  void _displayDialog(BuildContext context,
      List<FormPropertyValue> resultPropertyValues) async {
    var bloc = BlocProvider.of<DynamicFormBloc>(context);
    return showDialog(
      context: context,
      builder: (context) {
        return AlertDialog(
          title: flutter.Text('Form data'),
          content: flutter.Container(
            width: double.maxFinite,
            height: 300.0,
            child: ListView(
              padding: EdgeInsets.all(8.0),
              //map List of our data to the ListView
              children: resultPropertyValues
                  .map((riv) =>
                      flutter.Text('${riv.id} ${riv.property} ${riv.value}'))
                  .toList(),
            ),
          ),
          actions: <Widget>[
            FlatButton(
              child: flutter.Text('Ok'),
              onPressed: () {
                bloc.add(ClearFormDataEvent());
                Navigator.of(context).pop();
              },
            )
          ],
        );
      },
    );
  }
}

class DynamicFormButtonRow extends StatelessWidget {
  final DynamicFormState state;

  const DynamicFormButtonRow(
    this.state, {
    Key key,
  }) : super(key: key);

  @override
  Widget build(BuildContext context) {
    var bloc = BlocProvider.of<DynamicFormBloc>(context);
    return Row(
      mainAxisSize: MainAxisSize.max,
      mainAxisAlignment: MainAxisAlignment.center,
      children: <Widget>[
        OutlineButton(
          child: Row(
            children: <Widget>[
              flutter.Text("Cancel"),
              SizedBox(width: 10),
              Icon(Icons.cancel, color: Colors.red),
            ],
          ),
          onPressed: () {
            Navigator.pop(context);
          },
        ),
        SizedBox(width: 10),
        OutlineButton(
          child: Row(
            children: <Widget>[
              flutter.Text("Clear"),
              SizedBox(width: 10),
              Icon(Icons.clear_all, color: Colors.red),
            ],
          ),
          onPressed: () {
            bloc.add(ClearFormEvent());
          },
        ),
        SizedBox(width: 10),
        OutlineButton(
          child: Row(
            children: <Widget>[
              flutter.Text("Ok"),
              SizedBox(width: 10),
              Icon(
                Icons.check_circle,
                color: Colors.green,
              ),
            ],
          ),
          onPressed: state.isValid
              ? () {
                  bloc.add(RequestFormDataEvent());
                }
              : null,
        )
      ],
    );
  }
}
